@@ -1,10 +1,11 @@
+import re
 from argparse import ArgumentParser
 from contextlib import contextmanager
+from getpass import getpass
 from subprocess import check_output
 
 from pydropbear import start_ssh_server
 from pyngrok import ngrok
-import re
 
 
 def get_user_name():
@@ -23,13 +24,18 @@ if __name__ == "__main__":
     arg_parser = ArgumentParser()
     arg_parser.add_argument("ngrok_token", type=str)
     arg_parser.add_argument("--port", type=int, default=8443)
+    arg_parser.add_argument("--password", type=str)
     args = arg_parser.parse_args()
 
-    password = "1234"
-
     user_name = get_user_name()
+
     if user_name == "root":
-        check_output(["echo", "root:{}".format(password), "|", "chpasswd"])
+        if args.password is None:
+            password = getpass("It seems you are running under root user, please setup password: ")
+        else:
+            password = args.password
+
+        check_output(["echo", '"root:{}"'.format(password), "|", "chpasswd"])
 
     with ngrok_context(args.ngrok_token, args.port) as tunnel:
         url, port = re.findall(r"//([a-z0-9.]+):(\d+)", tunnel.public_url)[0]
